use clap::{Parser, Subcommand};
use config::{Config, File};
use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, Debug)]
pub struct AppConfig {
    pub database: DatabaseConfig,
    pub e621: e621Config
}

impl AppConfig {
    pub fn new() -> Self {
        let config = Config::builder()
            .add_source(File::with_name("config"))
            .build()
            .expect("Could not build config");

        return config
            .try_deserialize()
            .expect("Could not deserialize config");
    }
}

#[derive(Serialize, Deserialize, Debug)]
pub struct DatabaseConfig {
    pub url: String,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct e621Config {
    pub username: String,
    pub apikey: String
}

#[derive(Debug, Parser)]
pub struct Args {
    #[command(subcommand)]
    pub command: Command,
}

#[derive(Debug, Subcommand)]
pub enum Command {
    Import { path: String },
    Unposted
}
